@@ -180,8 +180,13 @@ class Connection(object):
 
         return resp
 
-    def get_all_buckets(self, headers=None):
-        response = self.make_request('GET', headers=headers)
+    def get_all_buckets(self, headers=None, project_ids=None):
+        query_args = {}
+        if project_ids is not None:
+            query_args = {
+                "projectIds": project_ids
+            }
+        response = self.make_request('GET', headers=headers, query_args=query_args)
         body = response.read()
         if response.status > 300:
             raise S3ResponseError(response.status, response.reason, body)
@@ -214,7 +219,7 @@ class Connection(object):
         else:
             raise S3ResponseError(response.status, response.reason, body)
 
-    def create_bucket(self, bucket_name, headers=None,
+    def create_bucket(self, bucket_name, headers=None, project_id=None,
                       location=None, policy=None):
         check_lowercase_bucketname(bucket_name)
 
@@ -228,7 +233,13 @@ class Connection(object):
         else:
             data = '<CreateBucketConfiguration><LocationConstraint>' + \
                    location + '</LocationConstraint></CreateBucketConfiguration>'
-        response = self.make_request('PUT', bucket_name, headers=headers,
+
+        query_args = {}
+        if project_id is not None:
+            query_args = {
+                "projectId": project_id
+            }
+        response = self.make_request('PUT', bucket_name, headers=headers, query_args=query_args,
                                      data=data)
         body = response.read()
         if response.status == 409:
